==> microsoft.bingads-12.13.5-sources.jar: com/microsoft/bingads/v13/adinsight/GetEstimatedBidByKeywordIdsResponse.java <==

package com.microsoft.bingads.v13.adinsight;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="KeywordEstimatedBids" type="{https://bingads.microsoft.com/AdInsight/v13}ArrayOfKeywordIdEstimatedBid" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "keywordEstimatedBids"
})
@XmlRootElement(name = "GetEstimatedBidByKeywordIdsResponse")
public class GetEstimatedBidByKeywordIdsResponse {

    @XmlElement(name = "KeywordEstimatedBids", nillable = true)
    protected ArrayOfKeywordIdEstimatedBid keywordEstimatedBids;

    /**
     * Gets the value of the keywordEstimatedBids property.
     * 
     * @return
     *     possible object is
     *     {@link ArrayOfKeywordIdEstimatedBid }
     *     
     */
    public ArrayOfKeywordIdEstimatedBid getKeywordEstimatedBids() {
        return keywordEstimatedBids;
    }

    /**
     * Sets the value of the keywordEstimatedBids property.
     * 
     * @param value
     *     allowed object is
     *     {@link ArrayOfKeywordIdEstimatedBid }
     *     
     */
    public void setKeywordEstimatedBids(ArrayOfKeywordIdEstimatedBid value) {
        this.keywordEstimatedBids = value;
    }

}

==> microsoft.bingads-13.0.23-sources.jar: com/microsoft/bingads/v13/adinsight/GetEstimatedBidByKeywordIdsResponse.java <==

package com.microsoft.bingads.v13.adinsight;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="KeywordEstimatedBids" type="{https://bingads.microsoft.com/AdInsight/v13}ArrayOfKeywordIdEstimatedBid" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "keywordEstimatedBids"
})
@XmlRootElement(name = "GetEstimatedBidByKeywordIdsResponse")
public class GetEstimatedBidByKeywordIdsResponse {

    @XmlElement(name = "KeywordEstimatedBids", nillable = true)
    protected ArrayOfKeywordIdEstimatedBid keywordEstimatedBids;

    /**
     * Gets the value of the keywordEstimatedBids property.
     * 
     * @return
     *     possible object is
     *     {@link ArrayOfKeywordIdEstimatedBid }
     *     
     */
    public ArrayOfKeywordIdEstimatedBid getKeywordEstimatedBids() {
        return keywordEstimatedBids;
    }

    /**
     * Sets the value of the keywordEstimatedBids property.
     * 
     * @param value
     *     allowed object is
     *     {@link ArrayOfKeywordIdEstimatedBid }
     *     
     */
    public void setKeywordEstimatedBids(ArrayOfKeywordIdEstimatedBid value) {
        this.keywordEstimatedBids = value;
    }

}
